@@ -51,7 +51,7 @@ class BaseNet(pl.LightningModule):
         n_classes : Optional[int],
         l1_strength : float = 0.0,
         sample_weight : Optional[Union["np.ndarray", "torch.Tensor"]] = None,
-        scheduler_config : Optional[Dict[str, Any]] = {'scheduler' : None, 'scheduler_config' : None},
+        scheduler_config : Optional[Dict[str, Any]] = {'scheduler' : None, 'scheduler_config' : {}},
         **config : Any
     ) -> None:
         r"""
@@ -304,7 +304,7 @@ class ConvNet(pl.LightningModule):
         n_classes : Optional[int] = None,
         sample_weight : Optional[Union["np.ndarray", "torch.Tensor"]] = None,
         dataformats : Optional[str] = "NCHW",
-        scheduler_config : Optional[Dict[str, Any]] = {'scheduler' : None, 'scheduler_config' : None},
+        scheduler_config : Optional[Dict[str, Any]] = {'scheduler' : None, 'scheduler_config' : {}},
         **config : Any
     )->None:
         r"""
@@ -542,7 +542,7 @@ class SegNet(pl.LightningModule):
         n_classes : Optional[int] = None,
         sample_weight : Optional[Union["np.ndarray", "torch.Tensor"]] = None,
         dataformats : Optional[str] = "NCHW",
-        scheduler_config : Optional[Dict[str, Any]] = {'scheduler' : None, 'scheduler_config' : None},
+        scheduler_config : Optional[Dict[str, Any]] = {'scheduler' : None, 'scheduler_config' : {}},
         **config : Any
     )->None:
         r"""
