@@ -62,7 +62,7 @@ class _MLP(nn.Module):
         weight_decay : float,
         l1_strength : float,
         momentum : float=0.9,
-        scheduler_config : Optional[Dict[str, Any]] = {'scheduler' : None, 'scheduler_config' : None},
+        scheduler_config : Optional[Dict[str, Any]] = {'scheduler' : None, 'scheduler_config' : {}},
         activation_type : str = "relu", # "relu" or "leaky_relu"
         negative_slope : Optional[float] = None, # negative slope for leaky relu   
         sample_weight : Optional[Union["np.ndarray", "torch.Tensor"]] = None
@@ -168,7 +168,7 @@ class MLP(BaseNet):
         dims : Union[int, Tuple[int]],
         n_classes : int,
         sample_weight : Optional[Union["torch.Tensor", "np.ndarray"]] = None,
-        scheduler_config : Optional[Dict[str, Any]] = {'scheduler' : None, 'scheduler_config' : None},
+        scheduler_config : Optional[Dict[str, Any]] = {'scheduler' : None, 'scheduler_config' : {}},
         **hparams
     ) -> None:
         r"""Multi-layer perceptron with identical # of hidden units.
@@ -282,7 +282,7 @@ class _ContractingMLP(nn.Module):
         lr : float,
         weight_decay : float,
         l1_strength : float,
-        scheduler_config : Optional[Dict[str, Any]] = {'scheduler' : None, 'scheduler_config' : None},
+        scheduler_config : Optional[Dict[str, Any]] = {'scheduler' : None, 'scheduler_config' : {}},
         activation_type : str = "relu",
         momentum : float=0.9,
         negative_slope : Optional[float] = None,
@@ -478,7 +478,7 @@ class ContractingMLP(BaseNet):
         dims : Union[int, Tuple[int]],
         n_classes : Optional[int],
         sample_weight : Optional[Union["torch.Tensor", "np.ndarray"]] = None,
-        scheduler_config: Optional[Dict[str, Any]] = {'scheduler' : None, 'scheduler_config' : None},
+        scheduler_config: Optional[Dict[str, Any]] = {'scheduler' : None, 'scheduler_config' : {}},
         **hparams : Any
     ) -> None:
         r"""Initialize ContractingMLP
@@ -609,7 +609,7 @@ class _CustomMLP(nn.Module):
         lr : float,
         weight_decay : float,
         l1_strength : float,
-        scheduler_config : Optional[Dict[str, Any]] = {'scheduler' : None, 'scheduler_config' : None},
+        scheduler_config : Optional[Dict[str, Any]] = {'scheduler' : None, 'scheduler_config' : {}},
         activation_type : str = "relu",
         negative_slope : Optional[float] = 0.2,
         n_hidden_units_list : Optional[List[int]] = None,
@@ -709,7 +709,7 @@ class CustomMLP(BaseNet):
         dims : Union[int, Tuple[int]],
         n_classes : int,
         sample_weight : Optional[Union["torch.Tensor", "np.ndarray"]] = None,
-        scheduler_config : Optional[Dict[str, Any]] = {'scheduler' : None, 'scheduler_config' : None},
+        scheduler_config : Optional[Dict[str, Any]] = {'scheduler' : None, 'scheduler_config' : {}},
         **hparams : Any
     ) -> None:
         
@@ -780,7 +780,7 @@ class _VGG(nn.Module):
         lr : float,
         weight_decay : float,
         l1_strength : float,
-        scheduler_config : Optional[Dict[str, Any]] = {'scheduler' : None, 'scheduler_config' : None},
+        scheduler_config : Optional[Dict[str, Any]] = {'scheduler' : None, 'scheduler_config' : {}},
         activation_type : str = "relu",
         negative_slope : Optional[float] = None, 
         momentum : float=0.9,
@@ -903,7 +903,7 @@ class VGG(ConvNet):
         n_classes : int,
         sample_weight : Optional[Union["torch.Tensor", "np.ndarray"]] = None,
         cfg : str ="VGG11",
-        scheduler_config : Optional[Dict[str, Any]] = {'scheduler' : None, 'scheduler_config' : None},
+        scheduler_config : Optional[Dict[str, Any]] = {'scheduler' : None, 'scheduler_config' : {}},
         **hparams
     ) -> None:
         
@@ -971,7 +971,7 @@ class _ResNet18(nn.Module):
         lr : float,
         weight_decay : float,
         l1_strength : float,
-        scheduler_config : Optional[Dict[str, Any]] = {'scheduler' : None, 'scheduler_config' : None},
+        scheduler_config : Optional[Dict[str, Any]] = {'scheduler' : None, 'scheduler_config' : {}},
         momentum : float=0.9,
         sample_weight : Optional[Union["torch.Tensor", "np.ndarray"]] = None
     )->None:
@@ -1008,7 +1008,7 @@ class ResNet18(ConvNet):
         dims : Union[int, Tuple[int]],
         n_classes : int,
         sample_weight : Optional[Union["torch.Tensor", "np.ndarray"]] = None,
-        scheduler_config : Optional[Dict[str, Any]] = {'scheduler' : None, 'scheduler_config' : None},
+        scheduler_config : Optional[Dict[str, Any]] = {'scheduler' : None, 'scheduler_config' : {}},
         **hparams
     )->None:
         self.dims = dims
@@ -1089,6 +1089,7 @@ class _UNet(nn.Module):
         negative_slope : Optional[float] = None,
         model_type : str = "UNet", # don't change this
         dataformats : Optional[str] = "NCHW", # number of samples, channels, height, width
+        scheduler_config : Optional[Dict[str, Any]] = {'scheduler' : None, 'scheduler_config' : {}},
         sample_weight : Optional[Union["torch.Tensor", "np.ndarray"]] = None
     ):
         self.n_classes = n_classes
@@ -1107,6 +1108,7 @@ class _UNet(nn.Module):
         self.negative_slope = negative_slope
         self.dataformats = dataformats
         self.momentum = momentum
+        self.scheduler_config = scheduler_config
 
         if self.n_layers < 1:
             raise ValueError(f"n_layers = {self.n_layers}, expected: n_layers > 0")
@@ -1148,6 +1150,7 @@ class UNet(SegNet):
         dims : Union[int, Tuple[int]],
         n_classes: int,
         sample_weight : Optional[Union["torch.Tensor", "np.ndarray"]] = None,
+        scheduler_config : Optional[Dict[str, Any]] = {'scheduler' : None, 'scheduler_config' : {}},
         **hparams : Any
     ):
 
@@ -1167,7 +1170,8 @@ class UNet(SegNet):
             'activation_type',
             'negative_slope',
             'dataformats',
-            'momentum'
+            'momentum',
+            'scheduler_config'
         ]
 
         default_parameter_dict = {
@@ -1226,6 +1230,7 @@ class _PixelCNN(nn.Module):
         hidden_channels : int=256,
         n_blocks : int=5,
         momentum : float=0.9,
+        scheduler_config : Optional[Dict[str, Any]] = {'scheduler' : None, 'scheduler_config' : {}},
         sample_weight : Optional[Union["torch.Tensor", "np.ndarray"]] = None
     ):
         super().__init__()
@@ -1245,6 +1250,7 @@ class _PixelCNN(nn.Module):
         self.dataformats = dataformats
         self.sample_weight = sample_weight
         self.momentum = momentum
+        self.scheduler_config = scheduler_config
 
         self.blocks = nn.ModuleList([self.conv_block(in_channels) for _ in range(n_blocks)])
 
@@ -1278,6 +1284,7 @@ class PixelCNN(SegNet):
         dims : Union[int, Tuple[int]],
         n_classes: int,
         sample_weight : Optional[Union["torch.Tensor", "np.ndarray"]] = None,
+        scheduler_config : Optional[Dict[str, Any]] = {'scheduler' : None, 'scheduler_config' : {}},
         **hparams : Any
     ):
         entire_keys = [
@@ -1296,7 +1303,8 @@ class PixelCNN(SegNet):
             'activation_type',
             'negative_slope',
             'dataformats',
-            'momentum'
+            'momentum',
+            'scheduler_config'
         ]
 
         default_parameter_dict = {
